"""Common configuration constants
"""

PROJECTNAME = 'ftw.billboard'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'BillboardAd': 'ftw.billboard: Add BillboardAd',
    'BillboardCategory': 'ftw.billboard: Add BillboardCategory',
}

TINYMCE_ALLOWED_BUTTONS = (
    'bg-basicmarkup',
    'bold-button',
    'italic-button',
    'list-ol-addbutton',
    'list-ul-addbutton',
    'definitionlist',
    'linklibdrawer-button',
    'removelink-button',
    'tabledrawer-button'
)
